# QONNX Tutorials

This folder contains a collection of Jupyter Notebook tutorials that cover QONNX internals, intended for new developers.
We recommend installing QONNX in development mode with notebooks option enabled, as follows:

```
git clone https://github.com/fastmachinelearning/qonnx
cd qonnx
virtualenv -p python3.8 venv
source venv/bin/activate
pip install -e .[testing,docs,notebooks]
cd notebooks
jupyter notebook .
# follow the link printed in the console to bring up Jupyter
```
